"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = loader;

var _loaderUtils = require("loader-utils");

var _schemaUtils = _interopRequireDefault(require("schema-utils"));

var _url = require("url");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const isURLInstance = str => {
  try {
    // eslint-disable-next-line no-new
    new _url.URL(str);
    return true;
  } catch (err) {
    return false;
  }
};

const isURL = str => {
  if (isURLInstance(str) || isURLInstance(`http:/${str}`) || isURLInstance(`http://${str}`) || isURLInstance(`http:/${str.replace('./', '/')}`)) {
    return true;
  }

  return false;
};

function processSource(source, options = {}) {
  const fromURL = options.from;
  const toURL = options.to;
  const mode = options.mode || 'production';
  const env = options.env || 'production';
  const NODE_ENV = process.env && process.env.NODE_ENV || '';
  const WEBPACK_MODE = process.env && process.env.WEBPACK_MODE || '';

  if (!fromURL || !toURL) {
    throw new Error(`Must set 'from' and 'to' options!`);
  } else if (!isURL(fromURL) || !isURL(toURL)) {
    throw new Error(`Cannot transform ${options.from} to ${options.to}!`);
  }

  if (NODE_ENV === env || WEBPACK_MODE === mode) {
    const escapedFromURL = fromURL.replace(/\//g, '\\/');
    const newSource = source.replace(new RegExp(`url\\(\\s*${escapedFromURL}`, 'g'), `url(${toURL}`).replace(new RegExp(`url\\(\\s*'${escapedFromURL}`, 'g'), `url('${toURL}`).replace(new RegExp(`url\\(\\s*"${escapedFromURL}`, 'g'), `url("${toURL}`);
    return newSource;
  }

  return source;
}

const schema = {
  type: 'object',
  properties: {
    from: {
      type: 'string'
    },
    to: {
      type: 'string'
    },
    mode: {
      type: 'string'
    },
    env: {
      type: 'string'
    }
  }
};

function loader(source) {
  const options = (0, _loaderUtils.getOptions)(this);
  (0, _schemaUtils.default)(schema, options, 'css-url-loader');
  const processedSource = processSource(source, options);
  return processedSource;
}